#!inc/bin/testml-cpan

"Type is string": 'foo'.Type    == 'str'
"Type is number": 42.Type       == 'num'
"Type is regex":  /^x.*$/.Type  == 'regex'
"Type is bool":   True.Type     == 'bool'
"Type is null":   Null.Type     == 'null'
"Type is list":   [1,2,3].Type  == 'list'
"Type is list":   *list.Type    == 'list'
"Type is hash":   *hash.Type    == 'hash'
"Type is error":  Error.Type    == 'error'
"Type is error":  x9.Catch.Type == 'error'

f = =>
  x = 1
"Type is func":   f.Type        == 'func'

a = []
"Type is none":   a:0.Type      == 'none'

"Type is none":   None.Type     == 'none'
"Type is native": mine.Type     == 'native'



=== Test 1
--- list(%)
[ 'foo', 123 ]

--- hash(%)
foo: 'bar'
bar: 123
