#!inc/bin/testml-cpan


*hash:bar == 'world'
  :"+ Hash lookup with static key"

hash-lookup(*hash, 'foo') == 'hello'
  :"Use hash in bridge function"

Env:PATH == get-env('PATH')
  :"Env var hash lookup"

=== Test 1
--- hash(%)
foo: 'hello'
bar: 'world'
