#!inc/bin/testml-cpan

*list.Count == *count
  :"Count a list point - +"

['foo', 42, True].Count == 3
  :"Count a literal list"

*list.Text == *text
  :"Join a list of lines into a Text string"

*text.Lines.Text == *text
  :"Split a text into lines then join back to text"

[].Text == ""
  :"Empty list turns into empty Text string"

list1 = "foo,bar,baz".Split(',')
list1.Count == 3
  :"3 elements in '{list1}'"

list1.Join('+') == 'foo+bar+baz'
  :"Join list '{list1}' into string '{Want}'"

=== Test 1
--- list(@)
line 1
line 2
line 3
--- ^text=list()
--- count: 3

=== Test 2
--- list(@): foo bar baz quux
--- count: 4
